# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double, integer


class CdiInputSpecification(AWSProperty):
    """
    `CdiInputSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-cdiinputspecification.html>`__
    """

    props: PropsDictType = {
        "Resolution": (str, False),
    }


class AacSettings(AWSProperty):
    """
    `AacSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-aacsettings.html>`__
    """

    props: PropsDictType = {
        "Bitrate": (double, False),
        "CodingMode": (str, False),
        "InputType": (str, False),
        "Profile": (str, False),
        "RateControlMode": (str, False),
        "RawFormat": (str, False),
        "SampleRate": (double, False),
        "Spec": (str, False),
        "VbrQuality": (str, False),
    }


class Ac3Settings(AWSProperty):
    """
    `Ac3Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-ac3settings.html>`__
    """

    props: PropsDictType = {
        "AttenuationControl": (str, False),
        "Bitrate": (double, False),
        "BitstreamMode": (str, False),
        "CodingMode": (str, False),
        "Dialnorm": (integer, False),
        "DrcProfile": (str, False),
        "LfeFilter": (str, False),
        "MetadataControl": (str, False),
    }


class Eac3AtmosSettings(AWSProperty):
    """
    `Eac3AtmosSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-eac3atmossettings.html>`__
    """

    props: PropsDictType = {
        "Bitrate": (double, False),
        "CodingMode": (str, False),
        "Dialnorm": (integer, False),
        "DrcLine": (str, False),
        "DrcRf": (str, False),
        "HeightTrim": (double, False),
        "SurroundTrim": (double, False),
    }


class Eac3Settings(AWSProperty):
    """
    `Eac3Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-eac3settings.html>`__
    """

    props: PropsDictType = {
        "AttenuationControl": (str, False),
        "Bitrate": (double, False),
        "BitstreamMode": (str, False),
        "CodingMode": (str, False),
        "DcFilter": (str, False),
        "Dialnorm": (integer, False),
        "DrcLine": (str, False),
        "DrcRf": (str, False),
        "LfeControl": (str, False),
        "LfeFilter": (str, False),
        "LoRoCenterMixLevel": (double, False),
        "LoRoSurroundMixLevel": (double, False),
        "LtRtCenterMixLevel": (double, False),
        "LtRtSurroundMixLevel": (double, False),
        "MetadataControl": (str, False),
        "PassthroughControl": (str, False),
        "PhaseControl": (str, False),
        "StereoDownmix": (str, False),
        "SurroundExMode": (str, False),
        "SurroundMode": (str, False),
    }


class Mp2Settings(AWSProperty):
    """
    `Mp2Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mp2settings.html>`__
    """

    props: PropsDictType = {
        "Bitrate": (double, False),
        "CodingMode": (str, False),
        "SampleRate": (double, False),
    }


class PassThroughSettings(AWSProperty):
    """
    `PassThroughSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-passthroughsettings.html>`__
    """

    props: PropsDictType = {}


class WavSettings(AWSProperty):
    """
    `WavSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-wavsettings.html>`__
    """

    props: PropsDictType = {
        "BitDepth": (double, False),
        "CodingMode": (str, False),
        "SampleRate": (double, False),
    }


class AudioCodecSettings(AWSProperty):
    """
    `AudioCodecSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiocodecsettings.html>`__
    """

    props: PropsDictType = {
        "AacSettings": (AacSettings, False),
        "Ac3Settings": (Ac3Settings, False),
        "Eac3AtmosSettings": (Eac3AtmosSettings, False),
        "Eac3Settings": (Eac3Settings, False),
        "Mp2Settings": (Mp2Settings, False),
        "PassThroughSettings": (PassThroughSettings, False),
        "WavSettings": (WavSettings, False),
    }


class AudioNormalizationSettings(AWSProperty):
    """
    `AudioNormalizationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audionormalizationsettings.html>`__
    """

    props: PropsDictType = {
        "Algorithm": (str, False),
        "AlgorithmControl": (str, False),
        "TargetLkfs": (double, False),
    }


class NielsenCBET(AWSProperty):
    """
    `NielsenCBET <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-nielsencbet.html>`__
    """

    props: PropsDictType = {
        "CbetCheckDigitString": (str, False),
        "CbetStepaside": (str, False),
        "Csid": (str, False),
    }


class NielsenNaesIiNw(AWSProperty):
    """
    `NielsenNaesIiNw <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-nielsennaesiinw.html>`__
    """

    props: PropsDictType = {
        "CheckDigitString": (str, False),
        "Sid": (double, False),
        "Timezone": (str, False),
    }


class NielsenWatermarksSettings(AWSProperty):
    """
    `NielsenWatermarksSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-nielsenwatermarkssettings.html>`__
    """

    props: PropsDictType = {
        "NielsenCbetSettings": (NielsenCBET, False),
        "NielsenDistributionType": (str, False),
        "NielsenNaesIiNwSettings": (NielsenNaesIiNw, False),
    }


class AudioWatermarkSettings(AWSProperty):
    """
    `AudioWatermarkSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiowatermarksettings.html>`__
    """

    props: PropsDictType = {
        "NielsenWatermarksSettings": (NielsenWatermarksSettings, False),
    }


class InputChannelLevel(AWSProperty):
    """
    `InputChannelLevel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputchannellevel.html>`__
    """

    props: PropsDictType = {
        "Gain": (integer, False),
        "InputChannel": (integer, False),
    }


class AudioChannelMapping(AWSProperty):
    """
    `AudioChannelMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiochannelmapping.html>`__
    """

    props: PropsDictType = {
        "InputChannelLevels": ([InputChannelLevel], False),
        "OutputChannel": (integer, False),
    }


class RemixSettings(AWSProperty):
    """
    `RemixSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-remixsettings.html>`__
    """

    props: PropsDictType = {
        "ChannelMappings": ([AudioChannelMapping], False),
        "ChannelsIn": (integer, False),
        "ChannelsOut": (integer, False),
    }


class AudioDescription(AWSProperty):
    """
    `AudioDescription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiodescription.html>`__
    """

    props: PropsDictType = {
        "AudioNormalizationSettings": (AudioNormalizationSettings, False),
        "AudioSelectorName": (str, False),
        "AudioType": (str, False),
        "AudioTypeControl": (str, False),
        "AudioWatermarkingSettings": (AudioWatermarkSettings, False),
        "CodecSettings": (AudioCodecSettings, False),
        "LanguageCode": (str, False),
        "LanguageCodeControl": (str, False),
        "Name": (str, False),
        "RemixSettings": (RemixSettings, False),
        "StreamName": (str, False),
    }


class InputLocation(AWSProperty):
    """
    `InputLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputlocation.html>`__
    """

    props: PropsDictType = {
        "PasswordParam": (str, False),
        "Uri": (str, False),
        "Username": (str, False),
    }


class AvailBlanking(AWSProperty):
    """
    `AvailBlanking <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-availblanking.html>`__
    """

    props: PropsDictType = {
        "AvailBlankingImage": (InputLocation, False),
        "State": (str, False),
    }


class Esam(AWSProperty):
    """
    `Esam <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-esam.html>`__
    """

    props: PropsDictType = {
        "AcquisitionPointId": (str, False),
        "AdAvailOffset": (integer, False),
        "PasswordParam": (str, False),
        "PoisEndpoint": (str, False),
        "Username": (str, False),
        "ZoneIdentity": (str, False),
    }


class Scte35SpliceInsert(AWSProperty):
    """
    `Scte35SpliceInsert <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte35spliceinsert.html>`__
    """

    props: PropsDictType = {
        "AdAvailOffset": (integer, False),
        "NoRegionalBlackoutFlag": (str, False),
        "WebDeliveryAllowedFlag": (str, False),
    }


class Scte35TimeSignalApos(AWSProperty):
    """
    `Scte35TimeSignalApos <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte35timesignalapos.html>`__
    """

    props: PropsDictType = {
        "AdAvailOffset": (integer, False),
        "NoRegionalBlackoutFlag": (str, False),
        "WebDeliveryAllowedFlag": (str, False),
    }


class AvailSettings(AWSProperty):
    """
    `AvailSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-availsettings.html>`__
    """

    props: PropsDictType = {
        "Esam": (Esam, False),
        "Scte35SpliceInsert": (Scte35SpliceInsert, False),
        "Scte35TimeSignalApos": (Scte35TimeSignalApos, False),
    }


class AvailConfiguration(AWSProperty):
    """
    `AvailConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-availconfiguration.html>`__
    """

    props: PropsDictType = {
        "AvailSettings": (AvailSettings, False),
    }


class BlackoutSlate(AWSProperty):
    """
    `BlackoutSlate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-blackoutslate.html>`__
    """

    props: PropsDictType = {
        "BlackoutSlateImage": (InputLocation, False),
        "NetworkEndBlackout": (str, False),
        "NetworkEndBlackoutImage": (InputLocation, False),
        "NetworkId": (str, False),
        "State": (str, False),
    }


class AribDestinationSettings(AWSProperty):
    """
    `AribDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-aribdestinationsettings.html>`__
    """

    props: PropsDictType = {}


class BurnInDestinationSettings(AWSProperty):
    """
    `BurnInDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-burnindestinationsettings.html>`__
    """

    props: PropsDictType = {
        "Alignment": (str, False),
        "BackgroundColor": (str, False),
        "BackgroundOpacity": (integer, False),
        "Font": (InputLocation, False),
        "FontColor": (str, False),
        "FontOpacity": (integer, False),
        "FontResolution": (integer, False),
        "FontSize": (str, False),
        "OutlineColor": (str, False),
        "OutlineSize": (integer, False),
        "ShadowColor": (str, False),
        "ShadowOpacity": (integer, False),
        "ShadowXOffset": (integer, False),
        "ShadowYOffset": (integer, False),
        "TeletextGridControl": (str, False),
        "XPosition": (integer, False),
        "YPosition": (integer, False),
    }


class DvbSubDestinationSettings(AWSProperty):
    """
    `DvbSubDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dvbsubdestinationsettings.html>`__
    """

    props: PropsDictType = {
        "Alignment": (str, False),
        "BackgroundColor": (str, False),
        "BackgroundOpacity": (integer, False),
        "Font": (InputLocation, False),
        "FontColor": (str, False),
        "FontOpacity": (integer, False),
        "FontResolution": (integer, False),
        "FontSize": (str, False),
        "OutlineColor": (str, False),
        "OutlineSize": (integer, False),
        "ShadowColor": (str, False),
        "ShadowOpacity": (integer, False),
        "ShadowXOffset": (integer, False),
        "ShadowYOffset": (integer, False),
        "TeletextGridControl": (str, False),
        "XPosition": (integer, False),
        "YPosition": (integer, False),
    }


class EbuTtDDestinationSettings(AWSProperty):
    """
    `EbuTtDDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-ebuttddestinationsettings.html>`__
    """

    props: PropsDictType = {
        "CopyrightHolder": (str, False),
        "FillLineGap": (str, False),
        "FontFamily": (str, False),
        "StyleControl": (str, False),
    }


class EmbeddedDestinationSettings(AWSProperty):
    """
    `EmbeddedDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-embeddeddestinationsettings.html>`__
    """

    props: PropsDictType = {}


class EmbeddedPlusScte20DestinationSettings(AWSProperty):
    """
    `EmbeddedPlusScte20DestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-embeddedplusscte20destinationsettings.html>`__
    """

    props: PropsDictType = {}


class RtmpCaptionInfoDestinationSettings(AWSProperty):
    """
    `RtmpCaptionInfoDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rtmpcaptioninfodestinationsettings.html>`__
    """

    props: PropsDictType = {}


class Scte20PlusEmbeddedDestinationSettings(AWSProperty):
    """
    `Scte20PlusEmbeddedDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte20plusembeddeddestinationsettings.html>`__
    """

    props: PropsDictType = {}


class Scte27DestinationSettings(AWSProperty):
    """
    `Scte27DestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte27destinationsettings.html>`__
    """

    props: PropsDictType = {}


class SmpteTtDestinationSettings(AWSProperty):
    """
    `SmpteTtDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-smptettdestinationsettings.html>`__
    """

    props: PropsDictType = {}


class TeletextDestinationSettings(AWSProperty):
    """
    `TeletextDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-teletextdestinationsettings.html>`__
    """

    props: PropsDictType = {}


class TtmlDestinationSettings(AWSProperty):
    """
    `TtmlDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-ttmldestinationsettings.html>`__
    """

    props: PropsDictType = {
        "StyleControl": (str, False),
    }


class WebvttDestinationSettings(AWSProperty):
    """
    `WebvttDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-webvttdestinationsettings.html>`__
    """

    props: PropsDictType = {
        "StyleControl": (str, False),
    }


class CaptionDestinationSettings(AWSProperty):
    """
    `CaptionDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captiondestinationsettings.html>`__
    """

    props: PropsDictType = {
        "AribDestinationSettings": (AribDestinationSettings, False),
        "BurnInDestinationSettings": (BurnInDestinationSettings, False),
        "DvbSubDestinationSettings": (DvbSubDestinationSettings, False),
        "EbuTtDDestinationSettings": (EbuTtDDestinationSettings, False),
        "EmbeddedDestinationSettings": (EmbeddedDestinationSettings, False),
        "EmbeddedPlusScte20DestinationSettings": (
            EmbeddedPlusScte20DestinationSettings,
            False,
        ),
        "RtmpCaptionInfoDestinationSettings": (
            RtmpCaptionInfoDestinationSettings,
            False,
        ),
        "Scte20PlusEmbeddedDestinationSettings": (
            Scte20PlusEmbeddedDestinationSettings,
            False,
        ),
        "Scte27DestinationSettings": (Scte27DestinationSettings, False),
        "SmpteTtDestinationSettings": (SmpteTtDestinationSettings, False),
        "TeletextDestinationSettings": (TeletextDestinationSettings, False),
        "TtmlDestinationSettings": (TtmlDestinationSettings, False),
        "WebvttDestinationSettings": (WebvttDestinationSettings, False),
    }


class CaptionDescription(AWSProperty):
    """
    `CaptionDescription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captiondescription.html>`__
    """

    props: PropsDictType = {
        "Accessibility": (str, False),
        "CaptionSelectorName": (str, False),
        "DestinationSettings": (CaptionDestinationSettings, False),
        "LanguageCode": (str, False),
        "LanguageDescription": (str, False),
        "Name": (str, False),
    }


class ColorCorrection(AWSProperty):
    """
    `ColorCorrection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-colorcorrection.html>`__
    """

    props: PropsDictType = {
        "InputColorSpace": (str, False),
        "OutputColorSpace": (str, False),
        "Uri": (str, False),
    }


class ColorCorrectionSettings(AWSProperty):
    """
    `ColorCorrectionSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-colorcorrectionsettings.html>`__
    """

    props: PropsDictType = {
        "GlobalColorCorrections": ([ColorCorrection], False),
    }


class FeatureActivations(AWSProperty):
    """
    `FeatureActivations <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-featureactivations.html>`__
    """

    props: PropsDictType = {
        "InputPrepareScheduleActions": (str, False),
        "OutputStaticImageOverlayScheduleActions": (str, False),
    }


class InputLossBehavior(AWSProperty):
    """
    `InputLossBehavior <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputlossbehavior.html>`__
    """

    props: PropsDictType = {
        "BlackFrameMsec": (integer, False),
        "InputLossImageColor": (str, False),
        "InputLossImageSlate": (InputLocation, False),
        "InputLossImageType": (str, False),
        "RepeatFrameMsec": (integer, False),
    }


class EpochLockingSettings(AWSProperty):
    """
    `EpochLockingSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-epochlockingsettings.html>`__
    """

    props: PropsDictType = {
        "CustomEpoch": (str, False),
        "JamSyncTime": (str, False),
    }


class PipelineLockingSettings(AWSProperty):
    """
    `PipelineLockingSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-pipelinelockingsettings.html>`__
    """

    props: PropsDictType = {}


class OutputLockingSettings(AWSProperty):
    """
    `OutputLockingSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputlockingsettings.html>`__
    """

    props: PropsDictType = {
        "EpochLockingSettings": (EpochLockingSettings, False),
        "PipelineLockingSettings": (PipelineLockingSettings, False),
    }


class GlobalConfiguration(AWSProperty):
    """
    `GlobalConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-globalconfiguration.html>`__
    """

    props: PropsDictType = {
        "InitialAudioGain": (integer, False),
        "InputEndAction": (str, False),
        "InputLossBehavior": (InputLossBehavior, False),
        "OutputLockingMode": (str, False),
        "OutputLockingSettings": (OutputLockingSettings, False),
        "OutputTimingSource": (str, False),
        "SupportLowFramerateInputs": (str, False),
    }


class HtmlMotionGraphicsSettings(AWSProperty):
    """
    `HtmlMotionGraphicsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-htmlmotiongraphicssettings.html>`__
    """

    props: PropsDictType = {}


class MotionGraphicsSettings(AWSProperty):
    """
    `MotionGraphicsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-motiongraphicssettings.html>`__
    """

    props: PropsDictType = {
        "HtmlMotionGraphicsSettings": (HtmlMotionGraphicsSettings, False),
    }


class MotionGraphicsConfiguration(AWSProperty):
    """
    `MotionGraphicsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-motiongraphicsconfiguration.html>`__
    """

    props: PropsDictType = {
        "MotionGraphicsInsertion": (str, False),
        "MotionGraphicsSettings": (MotionGraphicsSettings, False),
    }


class NielsenConfiguration(AWSProperty):
    """
    `NielsenConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-nielsenconfiguration.html>`__
    """

    props: PropsDictType = {
        "DistributorId": (str, False),
        "NielsenPcmToId3Tagging": (str, False),
    }


class DvbNitSettings(AWSProperty):
    """
    `DvbNitSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dvbnitsettings.html>`__
    """

    props: PropsDictType = {
        "NetworkId": (integer, False),
        "NetworkName": (str, False),
        "RepInterval": (integer, False),
    }


class DvbSdtSettings(AWSProperty):
    """
    `DvbSdtSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dvbsdtsettings.html>`__
    """

    props: PropsDictType = {
        "OutputSdt": (str, False),
        "RepInterval": (integer, False),
        "ServiceName": (str, False),
        "ServiceProviderName": (str, False),
    }


class DvbTdtSettings(AWSProperty):
    """
    `DvbTdtSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dvbtdtsettings.html>`__
    """

    props: PropsDictType = {
        "RepInterval": (integer, False),
    }


class M2tsSettings(AWSProperty):
    """
    `M2tsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-m2tssettings.html>`__
    """

    props: PropsDictType = {
        "AbsentInputAudioBehavior": (str, False),
        "Arib": (str, False),
        "AribCaptionsPid": (str, False),
        "AribCaptionsPidControl": (str, False),
        "AudioBufferModel": (str, False),
        "AudioFramesPerPes": (integer, False),
        "AudioPids": (str, False),
        "AudioStreamType": (str, False),
        "Bitrate": (integer, False),
        "BufferModel": (str, False),
        "CcDescriptor": (str, False),
        "DvbNitSettings": (DvbNitSettings, False),
        "DvbSdtSettings": (DvbSdtSettings, False),
        "DvbSubPids": (str, False),
        "DvbTdtSettings": (DvbTdtSettings, False),
        "DvbTeletextPid": (str, False),
        "Ebif": (str, False),
        "EbpAudioInterval": (str, False),
        "EbpLookaheadMs": (integer, False),
        "EbpPlacement": (str, False),
        "EcmPid": (str, False),
        "EsRateInPes": (str, False),
        "EtvPlatformPid": (str, False),
        "EtvSignalPid": (str, False),
        "FragmentTime": (double, False),
        "Klv": (str, False),
        "KlvDataPids": (str, False),
        "NielsenId3Behavior": (str, False),
        "NullPacketBitrate": (double, False),
        "PatInterval": (integer, False),
        "PcrControl": (str, False),
        "PcrPeriod": (integer, False),
        "PcrPid": (str, False),
        "PmtInterval": (integer, False),
        "PmtPid": (str, False),
        "ProgramNum": (integer, False),
        "RateMode": (str, False),
        "Scte27Pids": (str, False),
        "Scte35Control": (str, False),
        "Scte35Pid": (str, False),
        "Scte35PrerollPullupMilliseconds": (double, False),
        "SegmentationMarkers": (str, False),
        "SegmentationStyle": (str, False),
        "SegmentationTime": (double, False),
        "TimedMetadataBehavior": (str, False),
        "TimedMetadataPid": (str, False),
        "TransportStreamId": (integer, False),
        "VideoPid": (str, False),
    }


class RawSettings(AWSProperty):
    """
    `RawSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rawsettings.html>`__
    """

    props: PropsDictType = {}


class ArchiveContainerSettings(AWSProperty):
    """
    `ArchiveContainerSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-archivecontainersettings.html>`__
    """

    props: PropsDictType = {
        "M2tsSettings": (M2tsSettings, False),
        "RawSettings": (RawSettings, False),
    }


class ArchiveOutputSettings(AWSProperty):
    """
    `ArchiveOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-archiveoutputsettings.html>`__
    """

    props: PropsDictType = {
        "ContainerSettings": (ArchiveContainerSettings, False),
        "Extension": (str, False),
        "NameModifier": (str, False),
    }


class FrameCaptureOutputSettings(AWSProperty):
    """
    `FrameCaptureOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecaptureoutputsettings.html>`__
    """

    props: PropsDictType = {
        "NameModifier": (str, False),
    }


class AudioOnlyHlsSettings(AWSProperty):
    """
    `AudioOnlyHlsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audioonlyhlssettings.html>`__
    """

    props: PropsDictType = {
        "AudioGroupId": (str, False),
        "AudioOnlyImage": (InputLocation, False),
        "AudioTrackType": (str, False),
        "SegmentType": (str, False),
    }


class Fmp4HlsSettings(AWSProperty):
    """
    `Fmp4HlsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-fmp4hlssettings.html>`__
    """

    props: PropsDictType = {
        "AudioRenditionSets": (str, False),
        "NielsenId3Behavior": (str, False),
        "TimedMetadataBehavior": (str, False),
    }


class FrameCaptureHlsSettings(AWSProperty):
    """
    `FrameCaptureHlsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecapturehlssettings.html>`__
    """

    props: PropsDictType = {}


class M3u8Settings(AWSProperty):
    """
    `M3u8Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-m3u8settings.html>`__
    """

    props: PropsDictType = {
        "AudioFramesPerPes": (integer, False),
        "AudioPids": (str, False),
        "EcmPid": (str, False),
        "KlvBehavior": (str, False),
        "KlvDataPids": (str, False),
        "NielsenId3Behavior": (str, False),
        "PatInterval": (integer, False),
        "PcrControl": (str, False),
        "PcrPeriod": (integer, False),
        "PcrPid": (str, False),
        "PmtInterval": (integer, False),
        "PmtPid": (str, False),
        "ProgramNum": (integer, False),
        "Scte35Behavior": (str, False),
        "Scte35Pid": (str, False),
        "TimedMetadataBehavior": (str, False),
        "TimedMetadataPid": (str, False),
        "TransportStreamId": (integer, False),
        "VideoPid": (str, False),
    }


class StandardHlsSettings(AWSProperty):
    """
    `StandardHlsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-standardhlssettings.html>`__
    """

    props: PropsDictType = {
        "AudioRenditionSets": (str, False),
        "M3u8Settings": (M3u8Settings, False),
    }


class HlsSettings(AWSProperty):
    """
    `HlsSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlssettings.html>`__
    """

    props: PropsDictType = {
        "AudioOnlyHlsSettings": (AudioOnlyHlsSettings, False),
        "Fmp4HlsSettings": (Fmp4HlsSettings, False),
        "FrameCaptureHlsSettings": (FrameCaptureHlsSettings, False),
        "StandardHlsSettings": (StandardHlsSettings, False),
    }


class HlsOutputSettings(AWSProperty):
    """
    `HlsOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsoutputsettings.html>`__
    """

    props: PropsDictType = {
        "H265PackagingType": (str, False),
        "HlsSettings": (HlsSettings, False),
        "NameModifier": (str, False),
        "SegmentModifier": (str, False),
    }


class MediaPackageOutputSettings(AWSProperty):
    """
    `MediaPackageOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mediapackageoutputsettings.html>`__
    """

    props: PropsDictType = {}


class MsSmoothOutputSettings(AWSProperty):
    """
    `MsSmoothOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mssmoothoutputsettings.html>`__
    """

    props: PropsDictType = {
        "H265PackagingType": (str, False),
        "NameModifier": (str, False),
    }


class OutputLocationRef(AWSProperty):
    """
    `OutputLocationRef <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputlocationref.html>`__
    """

    props: PropsDictType = {
        "DestinationRefId": (str, False),
    }


class MultiplexOutputSettings(AWSProperty):
    """
    `MultiplexOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-multiplexoutputsettings.html>`__
    """

    props: PropsDictType = {
        "Destination": (OutputLocationRef, False),
    }


class RtmpOutputSettings(AWSProperty):
    """
    `RtmpOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rtmpoutputsettings.html>`__
    """

    props: PropsDictType = {
        "CertificateMode": (str, False),
        "ConnectionRetryInterval": (integer, False),
        "Destination": (OutputLocationRef, False),
        "NumRetries": (integer, False),
    }


class FecOutputSettings(AWSProperty):
    """
    `FecOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-fecoutputsettings.html>`__
    """

    props: PropsDictType = {
        "ColumnDepth": (integer, False),
        "IncludeFec": (str, False),
        "RowLength": (integer, False),
    }


class UdpContainerSettings(AWSProperty):
    """
    `UdpContainerSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-udpcontainersettings.html>`__
    """

    props: PropsDictType = {
        "M2tsSettings": (M2tsSettings, False),
    }


class UdpOutputSettings(AWSProperty):
    """
    `UdpOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-udpoutputsettings.html>`__
    """

    props: PropsDictType = {
        "BufferMsec": (integer, False),
        "ContainerSettings": (UdpContainerSettings, False),
        "Destination": (OutputLocationRef, False),
        "FecOutputSettings": (FecOutputSettings, False),
    }


class OutputSettings(AWSProperty):
    """
    `OutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputsettings.html>`__
    """

    props: PropsDictType = {
        "ArchiveOutputSettings": (ArchiveOutputSettings, False),
        "FrameCaptureOutputSettings": (FrameCaptureOutputSettings, False),
        "HlsOutputSettings": (HlsOutputSettings, False),
        "MediaPackageOutputSettings": (MediaPackageOutputSettings, False),
        "MsSmoothOutputSettings": (MsSmoothOutputSettings, False),
        "MultiplexOutputSettings": (MultiplexOutputSettings, False),
        "RtmpOutputSettings": (RtmpOutputSettings, False),
        "UdpOutputSettings": (UdpOutputSettings, False),
    }


class Output(AWSProperty):
    """
    `Output <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-output.html>`__
    """

    props: PropsDictType = {
        "AudioDescriptionNames": ([str], False),
        "CaptionDescriptionNames": ([str], False),
        "OutputName": (str, False),
        "OutputSettings": (OutputSettings, False),
        "VideoDescriptionName": (str, False),
    }


class ArchiveS3Settings(AWSProperty):
    """
    `ArchiveS3Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-archives3settings.html>`__
    """

    props: PropsDictType = {
        "CannedAcl": (str, False),
    }


class ArchiveCdnSettings(AWSProperty):
    """
    `ArchiveCdnSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-archivecdnsettings.html>`__
    """

    props: PropsDictType = {
        "ArchiveS3Settings": (ArchiveS3Settings, False),
    }


class ArchiveGroupSettings(AWSProperty):
    """
    `ArchiveGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-archivegroupsettings.html>`__
    """

    props: PropsDictType = {
        "ArchiveCdnSettings": (ArchiveCdnSettings, False),
        "Destination": (OutputLocationRef, False),
        "RolloverInterval": (integer, False),
    }


class FrameCaptureS3Settings(AWSProperty):
    """
    `FrameCaptureS3Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecaptures3settings.html>`__
    """

    props: PropsDictType = {
        "CannedAcl": (str, False),
    }


class FrameCaptureCdnSettings(AWSProperty):
    """
    `FrameCaptureCdnSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecapturecdnsettings.html>`__
    """

    props: PropsDictType = {
        "FrameCaptureS3Settings": (FrameCaptureS3Settings, False),
    }


class FrameCaptureGroupSettings(AWSProperty):
    """
    `FrameCaptureGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecapturegroupsettings.html>`__
    """

    props: PropsDictType = {
        "Destination": (OutputLocationRef, False),
        "FrameCaptureCdnSettings": (FrameCaptureCdnSettings, False),
    }


class CaptionLanguageMapping(AWSProperty):
    """
    `CaptionLanguageMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captionlanguagemapping.html>`__
    """

    props: PropsDictType = {
        "CaptionChannel": (integer, False),
        "LanguageCode": (str, False),
        "LanguageDescription": (str, False),
    }


class HlsAkamaiSettings(AWSProperty):
    """
    `HlsAkamaiSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsakamaisettings.html>`__
    """

    props: PropsDictType = {
        "ConnectionRetryInterval": (integer, False),
        "FilecacheDuration": (integer, False),
        "HttpTransferMode": (str, False),
        "NumRetries": (integer, False),
        "RestartDelay": (integer, False),
        "Salt": (str, False),
        "Token": (str, False),
    }


class HlsBasicPutSettings(AWSProperty):
    """
    `HlsBasicPutSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsbasicputsettings.html>`__
    """

    props: PropsDictType = {
        "ConnectionRetryInterval": (integer, False),
        "FilecacheDuration": (integer, False),
        "NumRetries": (integer, False),
        "RestartDelay": (integer, False),
    }


class HlsMediaStoreSettings(AWSProperty):
    """
    `HlsMediaStoreSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsmediastoresettings.html>`__
    """

    props: PropsDictType = {
        "ConnectionRetryInterval": (integer, False),
        "FilecacheDuration": (integer, False),
        "MediaStoreStorageClass": (str, False),
        "NumRetries": (integer, False),
        "RestartDelay": (integer, False),
    }


class HlsS3Settings(AWSProperty):
    """
    `HlsS3Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlss3settings.html>`__
    """

    props: PropsDictType = {
        "CannedAcl": (str, False),
    }


class HlsWebdavSettings(AWSProperty):
    """
    `HlsWebdavSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlswebdavsettings.html>`__
    """

    props: PropsDictType = {
        "ConnectionRetryInterval": (integer, False),
        "FilecacheDuration": (integer, False),
        "HttpTransferMode": (str, False),
        "NumRetries": (integer, False),
        "RestartDelay": (integer, False),
    }


class HlsCdnSettings(AWSProperty):
    """
    `HlsCdnSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlscdnsettings.html>`__
    """

    props: PropsDictType = {
        "HlsAkamaiSettings": (HlsAkamaiSettings, False),
        "HlsBasicPutSettings": (HlsBasicPutSettings, False),
        "HlsMediaStoreSettings": (HlsMediaStoreSettings, False),
        "HlsS3Settings": (HlsS3Settings, False),
        "HlsWebdavSettings": (HlsWebdavSettings, False),
    }


class StaticKeySettings(AWSProperty):
    """
    `StaticKeySettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-statickeysettings.html>`__
    """

    props: PropsDictType = {
        "KeyProviderServer": (InputLocation, False),
        "StaticKeyValue": (str, False),
    }


class KeyProviderSettings(AWSProperty):
    """
    `KeyProviderSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-keyprovidersettings.html>`__
    """

    props: PropsDictType = {
        "StaticKeySettings": (StaticKeySettings, False),
    }


class HlsGroupSettings(AWSProperty):
    """
    `HlsGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsgroupsettings.html>`__
    """

    props: PropsDictType = {
        "AdMarkers": ([str], False),
        "BaseUrlContent": (str, False),
        "BaseUrlContent1": (str, False),
        "BaseUrlManifest": (str, False),
        "BaseUrlManifest1": (str, False),
        "CaptionLanguageMappings": ([CaptionLanguageMapping], False),
        "CaptionLanguageSetting": (str, False),
        "ClientCache": (str, False),
        "CodecSpecification": (str, False),
        "ConstantIv": (str, False),
        "Destination": (OutputLocationRef, False),
        "DirectoryStructure": (str, False),
        "DiscontinuityTags": (str, False),
        "EncryptionType": (str, False),
        "HlsCdnSettings": (HlsCdnSettings, False),
        "HlsId3SegmentTagging": (str, False),
        "IFrameOnlyPlaylists": (str, False),
        "IncompleteSegmentBehavior": (str, False),
        "IndexNSegments": (integer, False),
        "InputLossAction": (str, False),
        "IvInManifest": (str, False),
        "IvSource": (str, False),
        "KeepSegments": (integer, False),
        "KeyFormat": (str, False),
        "KeyFormatVersions": (str, False),
        "KeyProviderSettings": (KeyProviderSettings, False),
        "ManifestCompression": (str, False),
        "ManifestDurationFormat": (str, False),
        "MinSegmentLength": (integer, False),
        "Mode": (str, False),
        "OutputSelection": (str, False),
        "ProgramDateTime": (str, False),
        "ProgramDateTimeClock": (str, False),
        "ProgramDateTimePeriod": (integer, False),
        "RedundantManifest": (str, False),
        "SegmentLength": (integer, False),
        "SegmentationMode": (str, False),
        "SegmentsPerSubdirectory": (integer, False),
        "StreamInfResolution": (str, False),
        "TimedMetadataId3Frame": (str, False),
        "TimedMetadataId3Period": (integer, False),
        "TimestampDeltaMilliseconds": (integer, False),
        "TsFileMode": (str, False),
    }


class MediaPackageGroupSettings(AWSProperty):
    """
    `MediaPackageGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mediapackagegroupsettings.html>`__
    """

    props: PropsDictType = {
        "Destination": (OutputLocationRef, False),
    }


class MsSmoothGroupSettings(AWSProperty):
    """
    `MsSmoothGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mssmoothgroupsettings.html>`__
    """

    props: PropsDictType = {
        "AcquisitionPointId": (str, False),
        "AudioOnlyTimecodeControl": (str, False),
        "CertificateMode": (str, False),
        "ConnectionRetryInterval": (integer, False),
        "Destination": (OutputLocationRef, False),
        "EventId": (str, False),
        "EventIdMode": (str, False),
        "EventStopBehavior": (str, False),
        "FilecacheDuration": (integer, False),
        "FragmentLength": (integer, False),
        "InputLossAction": (str, False),
        "NumRetries": (integer, False),
        "RestartDelay": (integer, False),
        "SegmentationMode": (str, False),
        "SendDelayMs": (integer, False),
        "SparseTrackType": (str, False),
        "StreamManifestBehavior": (str, False),
        "TimestampOffset": (str, False),
        "TimestampOffsetMode": (str, False),
    }


class MultiplexGroupSettings(AWSProperty):
    """
    `MultiplexGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-multiplexgroupsettings.html>`__
    """

    props: PropsDictType = {}


class RtmpGroupSettings(AWSProperty):
    """
    `RtmpGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rtmpgroupsettings.html>`__
    """

    props: PropsDictType = {
        "AdMarkers": ([str], False),
        "AuthenticationScheme": (str, False),
        "CacheFullBehavior": (str, False),
        "CacheLength": (integer, False),
        "CaptionData": (str, False),
        "IncludeFillerNalUnits": (str, False),
        "InputLossAction": (str, False),
        "RestartDelay": (integer, False),
    }


class UdpGroupSettings(AWSProperty):
    """
    `UdpGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-udpgroupsettings.html>`__
    """

    props: PropsDictType = {
        "InputLossAction": (str, False),
        "TimedMetadataId3Frame": (str, False),
        "TimedMetadataId3Period": (integer, False),
    }


class OutputGroupSettings(AWSProperty):
    """
    `OutputGroupSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputgroupsettings.html>`__
    """

    props: PropsDictType = {
        "ArchiveGroupSettings": (ArchiveGroupSettings, False),
        "FrameCaptureGroupSettings": (FrameCaptureGroupSettings, False),
        "HlsGroupSettings": (HlsGroupSettings, False),
        "MediaPackageGroupSettings": (MediaPackageGroupSettings, False),
        "MsSmoothGroupSettings": (MsSmoothGroupSettings, False),
        "MultiplexGroupSettings": (MultiplexGroupSettings, False),
        "RtmpGroupSettings": (RtmpGroupSettings, False),
        "UdpGroupSettings": (UdpGroupSettings, False),
    }


class OutputGroup(AWSProperty):
    """
    `OutputGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputgroup.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "OutputGroupSettings": (OutputGroupSettings, False),
        "Outputs": ([Output], False),
    }


class ThumbnailConfiguration(AWSProperty):
    """
    `ThumbnailConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-thumbnailconfiguration.html>`__
    """

    props: PropsDictType = {
        "State": (str, False),
    }


class TimecodeConfig(AWSProperty):
    """
    `TimecodeConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-timecodeconfig.html>`__
    """

    props: PropsDictType = {
        "Source": (str, False),
        "SyncThreshold": (integer, False),
    }


class TimecodeBurninSettings(AWSProperty):
    """
    `TimecodeBurninSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-timecodeburninsettings.html>`__
    """

    props: PropsDictType = {
        "FontSize": (str, False),
        "Position": (str, False),
        "Prefix": (str, False),
    }


class FrameCaptureSettings(AWSProperty):
    """
    `FrameCaptureSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-framecapturesettings.html>`__
    """

    props: PropsDictType = {
        "CaptureInterval": (integer, False),
        "CaptureIntervalUnits": (str, False),
        "TimecodeBurninSettings": (TimecodeBurninSettings, False),
    }


class ColorSpacePassthroughSettings(AWSProperty):
    """
    `ColorSpacePassthroughSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-colorspacepassthroughsettings.html>`__
    """

    props: PropsDictType = {}


class Rec601Settings(AWSProperty):
    """
    `Rec601Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rec601settings.html>`__
    """

    props: PropsDictType = {}


class Rec709Settings(AWSProperty):
    """
    `Rec709Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-rec709settings.html>`__
    """

    props: PropsDictType = {}


class H264ColorSpaceSettings(AWSProperty):
    """
    `H264ColorSpaceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h264colorspacesettings.html>`__
    """

    props: PropsDictType = {
        "ColorSpacePassthroughSettings": (ColorSpacePassthroughSettings, False),
        "Rec601Settings": (Rec601Settings, False),
        "Rec709Settings": (Rec709Settings, False),
    }


class TemporalFilterSettings(AWSProperty):
    """
    `TemporalFilterSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-temporalfiltersettings.html>`__
    """

    props: PropsDictType = {
        "PostFilterSharpening": (str, False),
        "Strength": (str, False),
    }


class H264FilterSettings(AWSProperty):
    """
    `H264FilterSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h264filtersettings.html>`__
    """

    props: PropsDictType = {
        "TemporalFilterSettings": (TemporalFilterSettings, False),
    }


class H264Settings(AWSProperty):
    """
    `H264Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h264settings.html>`__
    """

    props: PropsDictType = {
        "AdaptiveQuantization": (str, False),
        "AfdSignaling": (str, False),
        "Bitrate": (integer, False),
        "BufFillPct": (integer, False),
        "BufSize": (integer, False),
        "ColorMetadata": (str, False),
        "ColorSpaceSettings": (H264ColorSpaceSettings, False),
        "EntropyEncoding": (str, False),
        "FilterSettings": (H264FilterSettings, False),
        "FixedAfd": (str, False),
        "FlickerAq": (str, False),
        "ForceFieldPictures": (str, False),
        "FramerateControl": (str, False),
        "FramerateDenominator": (integer, False),
        "FramerateNumerator": (integer, False),
        "GopBReference": (str, False),
        "GopClosedCadence": (integer, False),
        "GopNumBFrames": (integer, False),
        "GopSize": (double, False),
        "GopSizeUnits": (str, False),
        "Level": (str, False),
        "LookAheadRateControl": (str, False),
        "MaxBitrate": (integer, False),
        "MinIInterval": (integer, False),
        "NumRefFrames": (integer, False),
        "ParControl": (str, False),
        "ParDenominator": (integer, False),
        "ParNumerator": (integer, False),
        "Profile": (str, False),
        "QualityLevel": (str, False),
        "QvbrQualityLevel": (integer, False),
        "RateControlMode": (str, False),
        "ScanType": (str, False),
        "SceneChangeDetect": (str, False),
        "Slices": (integer, False),
        "Softness": (integer, False),
        "SpatialAq": (str, False),
        "SubgopLength": (str, False),
        "Syntax": (str, False),
        "TemporalAq": (str, False),
        "TimecodeBurninSettings": (TimecodeBurninSettings, False),
        "TimecodeInsertion": (str, False),
    }


class DolbyVision81Settings(AWSProperty):
    """
    `DolbyVision81Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dolbyvision81settings.html>`__
    """

    props: PropsDictType = {}


class Hdr10Settings(AWSProperty):
    """
    `Hdr10Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hdr10settings.html>`__
    """

    props: PropsDictType = {
        "MaxCll": (integer, False),
        "MaxFall": (integer, False),
    }


class H265ColorSpaceSettings(AWSProperty):
    """
    `H265ColorSpaceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h265colorspacesettings.html>`__
    """

    props: PropsDictType = {
        "ColorSpacePassthroughSettings": (ColorSpacePassthroughSettings, False),
        "DolbyVision81Settings": (DolbyVision81Settings, False),
        "Hdr10Settings": (Hdr10Settings, False),
        "Rec601Settings": (Rec601Settings, False),
        "Rec709Settings": (Rec709Settings, False),
    }


class H265FilterSettings(AWSProperty):
    """
    `H265FilterSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h265filtersettings.html>`__
    """

    props: PropsDictType = {
        "TemporalFilterSettings": (TemporalFilterSettings, False),
    }


class H265Settings(AWSProperty):
    """
    `H265Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-h265settings.html>`__
    """

    props: PropsDictType = {
        "AdaptiveQuantization": (str, False),
        "AfdSignaling": (str, False),
        "AlternativeTransferFunction": (str, False),
        "Bitrate": (integer, False),
        "BufSize": (integer, False),
        "ColorMetadata": (str, False),
        "ColorSpaceSettings": (H265ColorSpaceSettings, False),
        "FilterSettings": (H265FilterSettings, False),
        "FixedAfd": (str, False),
        "FlickerAq": (str, False),
        "FramerateDenominator": (integer, False),
        "FramerateNumerator": (integer, False),
        "GopClosedCadence": (integer, False),
        "GopSize": (double, False),
        "GopSizeUnits": (str, False),
        "Level": (str, False),
        "LookAheadRateControl": (str, False),
        "MaxBitrate": (integer, False),
        "MinIInterval": (integer, False),
        "ParDenominator": (integer, False),
        "ParNumerator": (integer, False),
        "Profile": (str, False),
        "QvbrQualityLevel": (integer, False),
        "RateControlMode": (str, False),
        "ScanType": (str, False),
        "SceneChangeDetect": (str, False),
        "Slices": (integer, False),
        "Tier": (str, False),
        "TimecodeBurninSettings": (TimecodeBurninSettings, False),
        "TimecodeInsertion": (str, False),
    }


class Mpeg2FilterSettings(AWSProperty):
    """
    `Mpeg2FilterSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mpeg2filtersettings.html>`__
    """

    props: PropsDictType = {
        "TemporalFilterSettings": (TemporalFilterSettings, False),
    }


class Mpeg2Settings(AWSProperty):
    """
    `Mpeg2Settings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mpeg2settings.html>`__
    """

    props: PropsDictType = {
        "AdaptiveQuantization": (str, False),
        "AfdSignaling": (str, False),
        "ColorMetadata": (str, False),
        "ColorSpace": (str, False),
        "DisplayAspectRatio": (str, False),
        "FilterSettings": (Mpeg2FilterSettings, False),
        "FixedAfd": (str, False),
        "FramerateDenominator": (integer, False),
        "FramerateNumerator": (integer, False),
        "GopClosedCadence": (integer, False),
        "GopNumBFrames": (integer, False),
        "GopSize": (double, False),
        "GopSizeUnits": (str, False),
        "ScanType": (str, False),
        "SubgopLength": (str, False),
        "TimecodeBurninSettings": (TimecodeBurninSettings, False),
        "TimecodeInsertion": (str, False),
    }


class VideoCodecSettings(AWSProperty):
    """
    `VideoCodecSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videocodecsettings.html>`__
    """

    props: PropsDictType = {
        "FrameCaptureSettings": (FrameCaptureSettings, False),
        "H264Settings": (H264Settings, False),
        "H265Settings": (H265Settings, False),
        "Mpeg2Settings": (Mpeg2Settings, False),
    }


class VideoDescription(AWSProperty):
    """
    `VideoDescription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videodescription.html>`__
    """

    props: PropsDictType = {
        "CodecSettings": (VideoCodecSettings, False),
        "Height": (integer, False),
        "Name": (str, False),
        "RespondToAfd": (str, False),
        "ScalingBehavior": (str, False),
        "Sharpness": (integer, False),
        "Width": (integer, False),
    }


class EncoderSettings(AWSProperty):
    """
    `EncoderSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-encodersettings.html>`__
    """

    props: PropsDictType = {
        "AudioDescriptions": ([AudioDescription], False),
        "AvailBlanking": (AvailBlanking, False),
        "AvailConfiguration": (AvailConfiguration, False),
        "BlackoutSlate": (BlackoutSlate, False),
        "CaptionDescriptions": ([CaptionDescription], False),
        "ColorCorrectionSettings": (ColorCorrectionSettings, False),
        "FeatureActivations": (FeatureActivations, False),
        "GlobalConfiguration": (GlobalConfiguration, False),
        "MotionGraphicsConfiguration": (MotionGraphicsConfiguration, False),
        "NielsenConfiguration": (NielsenConfiguration, False),
        "OutputGroups": ([OutputGroup], False),
        "ThumbnailConfiguration": (ThumbnailConfiguration, False),
        "TimecodeConfig": (TimecodeConfig, False),
        "VideoDescriptions": ([VideoDescription], False),
    }


class AudioSilenceFailoverSettings(AWSProperty):
    """
    `AudioSilenceFailoverSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiosilencefailoversettings.html>`__
    """

    props: PropsDictType = {
        "AudioSelectorName": (str, False),
        "AudioSilenceThresholdMsec": (integer, False),
    }


class InputLossFailoverSettings(AWSProperty):
    """
    `InputLossFailoverSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputlossfailoversettings.html>`__
    """

    props: PropsDictType = {
        "InputLossThresholdMsec": (integer, False),
    }


class VideoBlackFailoverSettings(AWSProperty):
    """
    `VideoBlackFailoverSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoblackfailoversettings.html>`__
    """

    props: PropsDictType = {
        "BlackDetectThreshold": (double, False),
        "VideoBlackThresholdMsec": (integer, False),
    }


class FailoverConditionSettings(AWSProperty):
    """
    `FailoverConditionSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-failoverconditionsettings.html>`__
    """

    props: PropsDictType = {
        "AudioSilenceSettings": (AudioSilenceFailoverSettings, False),
        "InputLossSettings": (InputLossFailoverSettings, False),
        "VideoBlackSettings": (VideoBlackFailoverSettings, False),
    }


class FailoverCondition(AWSProperty):
    """
    `FailoverCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-failovercondition.html>`__
    """

    props: PropsDictType = {
        "FailoverConditionSettings": (FailoverConditionSettings, False),
    }


class AutomaticInputFailoverSettings(AWSProperty):
    """
    `AutomaticInputFailoverSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-automaticinputfailoversettings.html>`__
    """

    props: PropsDictType = {
        "ErrorClearTimeMsec": (integer, False),
        "FailoverConditions": ([FailoverCondition], False),
        "InputPreference": (str, False),
        "SecondaryInputId": (str, False),
    }


class AudioHlsRenditionSelection(AWSProperty):
    """
    `AudioHlsRenditionSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiohlsrenditionselection.html>`__
    """

    props: PropsDictType = {
        "GroupId": (str, False),
        "Name": (str, False),
    }


class AudioLanguageSelection(AWSProperty):
    """
    `AudioLanguageSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiolanguageselection.html>`__
    """

    props: PropsDictType = {
        "LanguageCode": (str, False),
        "LanguageSelectionPolicy": (str, False),
    }


class AudioPidSelection(AWSProperty):
    """
    `AudioPidSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiopidselection.html>`__
    """

    props: PropsDictType = {
        "Pid": (integer, False),
    }


class AudioDolbyEDecode(AWSProperty):
    """
    `AudioDolbyEDecode <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiodolbyedecode.html>`__
    """

    props: PropsDictType = {
        "ProgramSelection": (str, False),
    }


class AudioTrack(AWSProperty):
    """
    `AudioTrack <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiotrack.html>`__
    """

    props: PropsDictType = {
        "Track": (integer, False),
    }


class AudioTrackSelection(AWSProperty):
    """
    `AudioTrackSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audiotrackselection.html>`__
    """

    props: PropsDictType = {
        "DolbyEDecode": (AudioDolbyEDecode, False),
        "Tracks": ([AudioTrack], False),
    }


class AudioSelectorSettings(AWSProperty):
    """
    `AudioSelectorSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audioselectorsettings.html>`__
    """

    props: PropsDictType = {
        "AudioHlsRenditionSelection": (AudioHlsRenditionSelection, False),
        "AudioLanguageSelection": (AudioLanguageSelection, False),
        "AudioPidSelection": (AudioPidSelection, False),
        "AudioTrackSelection": (AudioTrackSelection, False),
    }


class AudioSelector(AWSProperty):
    """
    `AudioSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-audioselector.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "SelectorSettings": (AudioSelectorSettings, False),
    }


class AncillarySourceSettings(AWSProperty):
    """
    `AncillarySourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-ancillarysourcesettings.html>`__
    """

    props: PropsDictType = {
        "SourceAncillaryChannelNumber": (integer, False),
    }


class AribSourceSettings(AWSProperty):
    """
    `AribSourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-aribsourcesettings.html>`__
    """

    props: PropsDictType = {}


class DvbSubSourceSettings(AWSProperty):
    """
    `DvbSubSourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-dvbsubsourcesettings.html>`__
    """

    props: PropsDictType = {
        "OcrLanguage": (str, False),
        "Pid": (integer, False),
    }


class EmbeddedSourceSettings(AWSProperty):
    """
    `EmbeddedSourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-embeddedsourcesettings.html>`__
    """

    props: PropsDictType = {
        "Convert608To708": (str, False),
        "Scte20Detection": (str, False),
        "Source608ChannelNumber": (integer, False),
        "Source608TrackNumber": (integer, False),
    }


class Scte20SourceSettings(AWSProperty):
    """
    `Scte20SourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte20sourcesettings.html>`__
    """

    props: PropsDictType = {
        "Convert608To708": (str, False),
        "Source608ChannelNumber": (integer, False),
    }


class Scte27SourceSettings(AWSProperty):
    """
    `Scte27SourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-scte27sourcesettings.html>`__
    """

    props: PropsDictType = {
        "OcrLanguage": (str, False),
        "Pid": (integer, False),
    }


class CaptionRectangle(AWSProperty):
    """
    `CaptionRectangle <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captionrectangle.html>`__
    """

    props: PropsDictType = {
        "Height": (double, False),
        "LeftOffset": (double, False),
        "TopOffset": (double, False),
        "Width": (double, False),
    }


class TeletextSourceSettings(AWSProperty):
    """
    `TeletextSourceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-teletextsourcesettings.html>`__
    """

    props: PropsDictType = {
        "OutputRectangle": (CaptionRectangle, False),
        "PageNumber": (str, False),
    }


class CaptionSelectorSettings(AWSProperty):
    """
    `CaptionSelectorSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captionselectorsettings.html>`__
    """

    props: PropsDictType = {
        "AncillarySourceSettings": (AncillarySourceSettings, False),
        "AribSourceSettings": (AribSourceSettings, False),
        "DvbSubSourceSettings": (DvbSubSourceSettings, False),
        "EmbeddedSourceSettings": (EmbeddedSourceSettings, False),
        "Scte20SourceSettings": (Scte20SourceSettings, False),
        "Scte27SourceSettings": (Scte27SourceSettings, False),
        "TeletextSourceSettings": (TeletextSourceSettings, False),
    }


class CaptionSelector(AWSProperty):
    """
    `CaptionSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-captionselector.html>`__
    """

    props: PropsDictType = {
        "LanguageCode": (str, False),
        "Name": (str, False),
        "SelectorSettings": (CaptionSelectorSettings, False),
    }


class HlsInputSettings(AWSProperty):
    """
    `HlsInputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-hlsinputsettings.html>`__
    """

    props: PropsDictType = {
        "Bandwidth": (integer, False),
        "BufferSegments": (integer, False),
        "Retries": (integer, False),
        "RetryInterval": (integer, False),
        "Scte35Source": (str, False),
    }


class NetworkInputSettings(AWSProperty):
    """
    `NetworkInputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-networkinputsettings.html>`__
    """

    props: PropsDictType = {
        "HlsInputSettings": (HlsInputSettings, False),
        "ServerValidation": (str, False),
    }


class VideoSelectorColorSpaceSettings(AWSProperty):
    """
    `VideoSelectorColorSpaceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoselectorcolorspacesettings.html>`__
    """

    props: PropsDictType = {
        "Hdr10Settings": (Hdr10Settings, False),
    }


class VideoSelectorPid(AWSProperty):
    """
    `VideoSelectorPid <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoselectorpid.html>`__
    """

    props: PropsDictType = {
        "Pid": (integer, False),
    }


class VideoSelectorProgramId(AWSProperty):
    """
    `VideoSelectorProgramId <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoselectorprogramid.html>`__
    """

    props: PropsDictType = {
        "ProgramId": (integer, False),
    }


class VideoSelectorSettings(AWSProperty):
    """
    `VideoSelectorSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoselectorsettings.html>`__
    """

    props: PropsDictType = {
        "VideoSelectorPid": (VideoSelectorPid, False),
        "VideoSelectorProgramId": (VideoSelectorProgramId, False),
    }


class VideoSelector(AWSProperty):
    """
    `VideoSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-videoselector.html>`__
    """

    props: PropsDictType = {
        "ColorSpace": (str, False),
        "ColorSpaceSettings": (VideoSelectorColorSpaceSettings, False),
        "ColorSpaceUsage": (str, False),
        "SelectorSettings": (VideoSelectorSettings, False),
    }


class InputSettings(AWSProperty):
    """
    `InputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputsettings.html>`__
    """

    props: PropsDictType = {
        "AudioSelectors": ([AudioSelector], False),
        "CaptionSelectors": ([CaptionSelector], False),
        "DeblockFilter": (str, False),
        "DenoiseFilter": (str, False),
        "FilterStrength": (integer, False),
        "InputFilter": (str, False),
        "NetworkInputSettings": (NetworkInputSettings, False),
        "Scte35Pid": (integer, False),
        "Smpte2038DataPreference": (str, False),
        "SourceEndBehavior": (str, False),
        "VideoSelector": (VideoSelector, False),
    }


class InputAttachment(AWSProperty):
    """
    `InputAttachment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputattachment.html>`__
    """

    props: PropsDictType = {
        "AutomaticInputFailoverSettings": (AutomaticInputFailoverSettings, False),
        "InputAttachmentName": (str, False),
        "InputId": (str, False),
        "InputSettings": (InputSettings, False),
    }


class InputSpecification(AWSProperty):
    """
    `InputSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-inputspecification.html>`__
    """

    props: PropsDictType = {
        "Codec": (str, False),
        "MaximumBitrate": (str, False),
        "Resolution": (str, False),
    }


class MaintenanceCreateSettings(AWSProperty):
    """
    `MaintenanceCreateSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-maintenancecreatesettings.html>`__
    """

    props: PropsDictType = {
        "MaintenanceDay": (str, False),
        "MaintenanceStartTime": (str, False),
    }


class MediaPackageOutputDestinationSettings(AWSProperty):
    """
    `MediaPackageOutputDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-mediapackageoutputdestinationsettings.html>`__
    """

    props: PropsDictType = {
        "ChannelId": (str, False),
    }


class MultiplexProgramChannelDestinationSettings(AWSProperty):
    """
    `MultiplexProgramChannelDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-multiplexprogramchanneldestinationsettings.html>`__
    """

    props: PropsDictType = {
        "MultiplexId": (str, False),
        "ProgramName": (str, False),
    }


class OutputDestinationSettings(AWSProperty):
    """
    `OutputDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputdestinationsettings.html>`__
    """

    props: PropsDictType = {
        "PasswordParam": (str, False),
        "StreamName": (str, False),
        "Url": (str, False),
        "Username": (str, False),
    }


class OutputDestination(AWSProperty):
    """
    `OutputDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-outputdestination.html>`__
    """

    props: PropsDictType = {
        "Id": (str, False),
        "MediaPackageSettings": ([MediaPackageOutputDestinationSettings], False),
        "MultiplexSettings": (MultiplexProgramChannelDestinationSettings, False),
        "Settings": ([OutputDestinationSettings], False),
    }


class VpcOutputSettings(AWSProperty):
    """
    `VpcOutputSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-vpcoutputsettings.html>`__
    """

    props: PropsDictType = {
        "PublicAddressAllocationIds": ([str], False),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
    }


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-channel.html>`__
    """

    resource_type = "AWS::MediaLive::Channel"

    props: PropsDictType = {
        "CdiInputSpecification": (CdiInputSpecification, False),
        "ChannelClass": (str, False),
        "Destinations": ([OutputDestination], False),
        "EncoderSettings": (EncoderSettings, False),
        "InputAttachments": ([InputAttachment], False),
        "InputSpecification": (InputSpecification, False),
        "LogLevel": (str, False),
        "Maintenance": (MaintenanceCreateSettings, False),
        "Name": (str, False),
        "RoleArn": (str, False),
        "Tags": (dict, False),
        "Vpc": (VpcOutputSettings, False),
    }


class InputDestinationRequest(AWSProperty):
    """
    `InputDestinationRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-inputdestinationrequest.html>`__
    """

    props: PropsDictType = {
        "StreamName": (str, False),
    }


class InputDeviceSettings(AWSProperty):
    """
    `InputDeviceSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-inputdevicesettings.html>`__
    """

    props: PropsDictType = {
        "Id": (str, False),
    }


class InputSourceRequest(AWSProperty):
    """
    `InputSourceRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-inputsourcerequest.html>`__
    """

    props: PropsDictType = {
        "PasswordParam": (str, False),
        "Url": (str, False),
        "Username": (str, False),
    }


class InputVpcRequest(AWSProperty):
    """
    `InputVpcRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-inputvpcrequest.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
    }


class MediaConnectFlowRequest(AWSProperty):
    """
    `MediaConnectFlowRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-mediaconnectflowrequest.html>`__
    """

    props: PropsDictType = {
        "FlowArn": (str, False),
    }


class Input(AWSObject):
    """
    `Input <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-input.html>`__
    """

    resource_type = "AWS::MediaLive::Input"

    props: PropsDictType = {
        "Destinations": ([InputDestinationRequest], False),
        "InputDevices": ([InputDeviceSettings], False),
        "InputSecurityGroups": ([str], False),
        "MediaConnectFlows": ([MediaConnectFlowRequest], False),
        "Name": (str, False),
        "RoleArn": (str, False),
        "Sources": ([InputSourceRequest], False),
        "Tags": (dict, False),
        "Type": (str, False),
        "Vpc": (InputVpcRequest, False),
    }


class InputWhitelistRuleCidr(AWSProperty):
    """
    `InputWhitelistRuleCidr <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-inputsecuritygroup-inputwhitelistrulecidr.html>`__
    """

    props: PropsDictType = {
        "Cidr": (str, False),
    }


class InputSecurityGroup(AWSObject):
    """
    `InputSecurityGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-inputsecuritygroup.html>`__
    """

    resource_type = "AWS::MediaLive::InputSecurityGroup"

    props: PropsDictType = {
        "Tags": (dict, False),
        "WhitelistRules": ([InputWhitelistRuleCidr], False),
    }


class MultiplexMediaConnectOutputDestinationSettings(AWSProperty):
    """
    `MultiplexMediaConnectOutputDestinationSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplex-multiplexmediaconnectoutputdestinationsettings.html>`__
    """

    props: PropsDictType = {
        "EntitlementArn": (str, False),
    }


class MultiplexOutputDestination(AWSProperty):
    """
    `MultiplexOutputDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplex-multiplexoutputdestination.html>`__
    """

    props: PropsDictType = {
        "MultiplexMediaConnectOutputDestinationSettings": (
            MultiplexMediaConnectOutputDestinationSettings,
            False,
        ),
    }


class MultiplexSettings(AWSProperty):
    """
    `MultiplexSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplex-multiplexsettings.html>`__
    """

    props: PropsDictType = {
        "MaximumVideoBufferDelayMilliseconds": (integer, False),
        "TransportStreamBitrate": (integer, True),
        "TransportStreamId": (integer, True),
        "TransportStreamReservedBitrate": (integer, False),
    }


class Multiplex(AWSObject):
    """
    `Multiplex <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-multiplex.html>`__
    """

    resource_type = "AWS::MediaLive::Multiplex"

    props: PropsDictType = {
        "AvailabilityZones": ([str], True),
        "Destinations": ([MultiplexOutputDestination], False),
        "MultiplexSettings": (MultiplexSettings, True),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class MultiplexProgramPacketIdentifiersMap(AWSProperty):
    """
    `MultiplexProgramPacketIdentifiersMap <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexprogrampacketidentifiersmap.html>`__
    """

    props: PropsDictType = {
        "AudioPids": ([integer], False),
        "DvbSubPids": ([integer], False),
        "DvbTeletextPid": (integer, False),
        "EtvPlatformPid": (integer, False),
        "EtvSignalPid": (integer, False),
        "KlvDataPids": ([integer], False),
        "PcrPid": (integer, False),
        "PmtPid": (integer, False),
        "PrivateMetadataPid": (integer, False),
        "Scte27Pids": ([integer], False),
        "Scte35Pid": (integer, False),
        "TimedMetadataPid": (integer, False),
        "VideoPid": (integer, False),
    }


class MultiplexProgramPipelineDetail(AWSProperty):
    """
    `MultiplexProgramPipelineDetail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexprogrampipelinedetail.html>`__
    """

    props: PropsDictType = {
        "ActiveChannelPipeline": (str, False),
        "PipelineId": (str, False),
    }


class MultiplexProgramServiceDescriptor(AWSProperty):
    """
    `MultiplexProgramServiceDescriptor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexprogramservicedescriptor.html>`__
    """

    props: PropsDictType = {
        "ProviderName": (str, True),
        "ServiceName": (str, True),
    }


class MultiplexStatmuxVideoSettings(AWSProperty):
    """
    `MultiplexStatmuxVideoSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexstatmuxvideosettings.html>`__
    """

    props: PropsDictType = {
        "MaximumBitrate": (integer, False),
        "MinimumBitrate": (integer, False),
        "Priority": (integer, False),
    }


class MultiplexVideoSettings(AWSProperty):
    """
    `MultiplexVideoSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexvideosettings.html>`__
    """

    props: PropsDictType = {
        "ConstantBitrate": (integer, False),
        "StatmuxSettings": (MultiplexStatmuxVideoSettings, False),
    }


class MultiplexProgramSettings(AWSProperty):
    """
    `MultiplexProgramSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-multiplexprogram-multiplexprogramsettings.html>`__
    """

    props: PropsDictType = {
        "PreferredChannelPipeline": (str, False),
        "ProgramNumber": (integer, True),
        "ServiceDescriptor": (MultiplexProgramServiceDescriptor, False),
        "VideoSettings": (MultiplexVideoSettings, False),
    }


class Multiplexprogram(AWSObject):
    """
    `Multiplexprogram <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-multiplexprogram.html>`__
    """

    resource_type = "AWS::MediaLive::Multiplexprogram"

    props: PropsDictType = {
        "ChannelId": (str, False),
        "MultiplexId": (str, False),
        "MultiplexProgramSettings": (MultiplexProgramSettings, False),
        "PacketIdentifiersMap": (MultiplexProgramPacketIdentifiersMap, False),
        "PipelineDetails": ([MultiplexProgramPipelineDetail], False),
        "PreferredChannelPipeline": (str, False),
        "ProgramName": (str, False),
    }


class InputDeviceRequest(AWSProperty):
    """
    `InputDeviceRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-input-inputdevicerequest.html>`__
    """

    props: PropsDictType = {
        "Id": (str, False),
    }


class MaintenanceUpdateSettings(AWSProperty):
    """
    `MaintenanceUpdateSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-medialive-channel-maintenanceupdatesettings.html>`__
    """

    props: PropsDictType = {
        "MaintenanceDay": (str, False),
        "MaintenanceScheduledDate": (str, False),
        "MaintenanceStartTime": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean


class AwsLambda(AWSProperty):
    """
    `AwsLambda <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-awslambda.html>`__
    """

    props: PropsDictType = {
        "FunctionArn": (str, True),
        "FunctionPayload": (str, False),
    }


class ContentTransformation(AWSProperty):
    """
    `ContentTransformation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-contenttransformation.html>`__
    """

    props: PropsDictType = {
        "AwsLambda": (AwsLambda, True),
    }


class TransformationConfiguration(AWSProperty):
    """
    `TransformationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-transformationconfiguration.html>`__
    """

    props: PropsDictType = {
        "Actions": ([str], True),
        "ContentTransformation": (ContentTransformation, True),
    }


class ObjectLambdaConfiguration(AWSProperty):
    """
    `ObjectLambdaConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-objectlambdaconfiguration.html>`__
    """

    props: PropsDictType = {
        "AllowedFeatures": ([str], False),
        "CloudWatchMetricsEnabled": (boolean, False),
        "SupportingAccessPoint": (str, True),
        "TransformationConfigurations": ([TransformationConfiguration], True),
    }


class AccessPoint(AWSObject):
    """
    `AccessPoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-s3objectlambda-accesspoint.html>`__
    """

    resource_type = "AWS::S3ObjectLambda::AccessPoint"

    props: PropsDictType = {
        "Name": (str, False),
        "ObjectLambdaConfiguration": (ObjectLambdaConfiguration, True),
    }


class AccessPointPolicy(AWSObject):
    """
    `AccessPointPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-s3objectlambda-accesspointpolicy.html>`__
    """

    resource_type = "AWS::S3ObjectLambda::AccessPointPolicy"

    props: PropsDictType = {
        "ObjectLambdaAccessPoint": (str, True),
        "PolicyDocument": (dict, True),
    }


class Alias(AWSProperty):
    """
    `Alias <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-alias.html>`__
    """

    props: PropsDictType = {
        "Status": (str, False),
        "Value": (str, True),
    }


class PublicAccessBlockConfiguration(AWSProperty):
    """
    `PublicAccessBlockConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3objectlambda-accesspoint-publicaccessblockconfiguration.html>`__
    """

    props: PropsDictType = {
        "BlockPublicAcls": (boolean, False),
        "BlockPublicPolicy": (boolean, False),
        "IgnorePublicAcls": (boolean, False),
        "RestrictPublicBuckets": (boolean, False),
    }



import unittest

from troposphere import Template

single_mapping = """\
{
 "Mappings": {
  "map": {
   "n": "v"
  }
 },
 "Resources": {}
}"""

multiple_mappings = """\
{
 "Mappings": {
  "map": {
   "k1": {
    "n1": "v1"
   },
   "k2": {
    "n2": "v2"
   }
  }
 },
 "Resources": {}
}"""


class TestMappings(unittest.TestCase):
    def test_single_mapping(self):
        template = Template()
        template.add_mapping("map", {"n": "v"})
        json = template.to_json()
        self.assertEqual(single_mapping, json)

    def test_multiple_mappings(self):
        template = Template()
        template.add_mapping("map", {"k1": {"n1": "v1"}})
        template.add_mapping("map", {"k2": {"n2": "v2"}})
        json = template.to_json()
        self.assertEqual(multiple_mappings, json)


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from ..compat import validate_policytype
from . import integer_range, tags_or_list


def policytypes(policy):
    """
    Property: Key.KeyPolicy
    """
    return validate_policytype(policy)


def key_usage_type(key):
    """
    Property: Key.KeyUsage
    """
    valid_values = ["ENCRYPT_DECRYPT", "SIGN_VERIFY"]
    if key not in valid_values:
        raise ValueError('KeyUsage must be one of: "%s"' % (", ".join(valid_values)))
    return key


def validate_pending_window_in_days(port):
    """
    Property: Key.PendingWindowInDays
    """
    return integer_range(7, 30)(port)


def validate_tags_or_list(x):
    """
    Property: Key.Tags
    """
    return tags_or_list(x)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.amazonmq import validate_tags_or_list


class ConfigurationId(AWSProperty):
    """
    `ConfigurationId <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-configurationassociation-configurationid.html>`__
    """

    props: PropsDictType = {
        "Id": (str, True),
        "Revision": (integer, True),
    }


class EncryptionOptions(AWSProperty):
    """
    `EncryptionOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-encryptionoptions.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
        "UseAwsOwnedKey": (boolean, True),
    }


class LdapServerMetadata(AWSProperty):
    """
    `LdapServerMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html>`__
    """

    props: PropsDictType = {
        "Hosts": ([str], True),
        "RoleBase": (str, True),
        "RoleName": (str, False),
        "RoleSearchMatching": (str, True),
        "RoleSearchSubtree": (boolean, False),
        "ServiceAccountPassword": (str, True),
        "ServiceAccountUsername": (str, True),
        "UserBase": (str, True),
        "UserRoleName": (str, False),
        "UserSearchMatching": (str, True),
        "UserSearchSubtree": (boolean, False),
    }


class LogsConfiguration(AWSProperty):
    """
    `LogsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-loglist.html>`__
    """

    props: PropsDictType = {
        "Audit": (boolean, False),
        "General": (boolean, False),
    }


class MaintenanceWindow(AWSProperty):
    """
    `MaintenanceWindow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-maintenancewindow.html>`__
    """

    props: PropsDictType = {
        "DayOfWeek": (str, True),
        "TimeOfDay": (str, True),
        "TimeZone": (str, True),
    }


class User(AWSProperty):
    """
    `User <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-user.html>`__
    """

    props: PropsDictType = {
        "ConsoleAccess": (boolean, False),
        "Groups": ([str], False),
        "Password": (str, True),
        "ReplicationUser": (boolean, False),
        "Username": (str, True),
    }


class Broker(AWSObject):
    """
    `Broker <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html>`__
    """

    resource_type = "AWS::AmazonMQ::Broker"

    props: PropsDictType = {
        "AuthenticationStrategy": (str, False),
        "AutoMinorVersionUpgrade": (boolean, True),
        "BrokerName": (str, True),
        "Configuration": (ConfigurationId, False),
        "DataReplicationMode": (str, False),
        "DataReplicationPrimaryBrokerArn": (str, False),
        "DeploymentMode": (str, True),
        "EncryptionOptions": (EncryptionOptions, False),
        "EngineType": (str, True),
        "EngineVersion": (str, True),
        "HostInstanceType": (str, True),
        "LdapServerMetadata": (LdapServerMetadata, False),
        "Logs": (LogsConfiguration, False),
        "MaintenanceWindowStartTime": (MaintenanceWindow, False),
        "PubliclyAccessible": (boolean, True),
        "SecurityGroups": ([str], False),
        "StorageType": (str, False),
        "SubnetIds": ([str], False),
        "Tags": (validate_tags_or_list, False),
        "Users": ([User], True),
    }


class Configuration(AWSObject):
    """
    `Configuration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-configuration.html>`__
    """

    resource_type = "AWS::AmazonMQ::Configuration"

    props: PropsDictType = {
        "AuthenticationStrategy": (str, False),
        "Data": (str, True),
        "Description": (str, False),
        "EngineType": (str, True),
        "EngineVersion": (str, True),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class ConfigurationAssociation(AWSObject):
    """
    `ConfigurationAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-configurationassociation.html>`__
    """

    resource_type = "AWS::AmazonMQ::ConfigurationAssociation"

    props: PropsDictType = {
        "Broker": (str, True),
        "Configuration": (ConfigurationId, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType


class DefaultViewAssociation(AWSObject):
    """
    `DefaultViewAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourceexplorer2-defaultviewassociation.html>`__
    """

    resource_type = "AWS::ResourceExplorer2::DefaultViewAssociation"

    props: PropsDictType = {
        "ViewArn": (str, True),
    }


class Index(AWSObject):
    """
    `Index <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourceexplorer2-index.html>`__
    """

    resource_type = "AWS::ResourceExplorer2::Index"

    props: PropsDictType = {
        "Tags": (dict, False),
        "Type": (str, True),
    }


class IncludedProperty(AWSProperty):
    """
    `IncludedProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourceexplorer2-view-includedproperty.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
    }


class SearchFilter(AWSProperty):
    """
    `SearchFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourceexplorer2-view-searchfilter.html>`__
    """

    props: PropsDictType = {
        "FilterString": (str, True),
    }


class View(AWSObject):
    """
    `View <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourceexplorer2-view.html>`__
    """

    resource_type = "AWS::ResourceExplorer2::View"

    props: PropsDictType = {
        "Filters": (SearchFilter, False),
        "IncludedProperties": ([IncludedProperty], False),
        "Scope": (str, False),
        "Tags": (dict, False),
        "ViewName": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer
from .validators.firehose import (
    delivery_stream_type_validator,
    index_rotation_period_validator,
    processor_type_validator,
    s3_backup_mode_elastic_search_validator,
    s3_backup_mode_extended_s3_validator,
)


class AmazonOpenSearchServerlessBufferingHints(AWSProperty):
    """
    `AmazonOpenSearchServerlessBufferingHints <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchserverlessbufferinghints.html>`__
    """

    props: PropsDictType = {
        "IntervalInSeconds": (integer, False),
        "SizeInMBs": (integer, False),
    }


class AmazonOpenSearchServerlessRetryOptions(AWSProperty):
    """
    `AmazonOpenSearchServerlessRetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchserverlessretryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class CloudWatchLoggingOptions(AWSProperty):
    """
    `CloudWatchLoggingOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-cloudwatchloggingoptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "LogGroupName": (str, False),
        "LogStreamName": (str, False),
    }


class ProcessorParameter(AWSProperty):
    """
    `ProcessorParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-processorparameter.html>`__
    """

    props: PropsDictType = {
        "ParameterName": (str, True),
        "ParameterValue": (str, True),
    }


class Processor(AWSProperty):
    """
    `Processor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-processor.html>`__
    """

    props: PropsDictType = {
        "Parameters": ([ProcessorParameter], False),
        "Type": (processor_type_validator, True),
    }


class ProcessingConfiguration(AWSProperty):
    """
    `ProcessingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-processingconfiguration.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "Processors": ([Processor], False),
    }


class BufferingHints(AWSProperty):
    """
    `BufferingHints <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-bufferinghints.html>`__
    """

    props: PropsDictType = {
        "IntervalInSeconds": (integer, False),
        "SizeInMBs": (integer, False),
    }


class KMSEncryptionConfig(AWSProperty):
    """
    `KMSEncryptionConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-kmsencryptionconfig.html>`__
    """

    props: PropsDictType = {
        "AWSKMSKeyARN": (str, True),
    }


class EncryptionConfiguration(AWSProperty):
    """
    `EncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-encryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KMSEncryptionConfig": (KMSEncryptionConfig, False),
        "NoEncryptionConfig": (str, False),
    }


class S3DestinationConfiguration(AWSProperty):
    """
    `S3DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-s3destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketARN": (str, True),
        "BufferingHints": (BufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "CompressionFormat": (str, False),
        "EncryptionConfiguration": (EncryptionConfiguration, False),
        "ErrorOutputPrefix": (str, False),
        "Prefix": (str, False),
        "RoleARN": (str, True),
    }


class VpcConfiguration(AWSProperty):
    """
    `VpcConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-vpcconfiguration.html>`__
    """

    props: PropsDictType = {
        "RoleARN": (str, True),
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
    }


class AmazonOpenSearchServerlessDestinationConfiguration(AWSProperty):
    """
    `AmazonOpenSearchServerlessDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchserverlessdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BufferingHints": (AmazonOpenSearchServerlessBufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "CollectionEndpoint": (str, False),
        "IndexName": (str, True),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (AmazonOpenSearchServerlessRetryOptions, False),
        "RoleARN": (str, True),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3DestinationConfiguration, True),
        "VpcConfiguration": (VpcConfiguration, False),
    }


class AmazonopensearchserviceBufferingHints(AWSProperty):
    """
    `AmazonopensearchserviceBufferingHints <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchservicebufferinghints.html>`__
    """

    props: PropsDictType = {
        "IntervalInSeconds": (integer, False),
        "SizeInMBs": (integer, False),
    }


class AmazonopensearchserviceRetryOptions(AWSProperty):
    """
    `AmazonopensearchserviceRetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchserviceretryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class DocumentIdOptions(AWSProperty):
    """
    `DocumentIdOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-documentidoptions.html>`__
    """

    props: PropsDictType = {
        "DefaultDocumentIdFormat": (str, True),
    }


class AmazonopensearchserviceDestinationConfiguration(AWSProperty):
    """
    `AmazonopensearchserviceDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-amazonopensearchservicedestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BufferingHints": (AmazonopensearchserviceBufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "ClusterEndpoint": (str, False),
        "DocumentIdOptions": (DocumentIdOptions, False),
        "DomainARN": (str, False),
        "IndexName": (str, True),
        "IndexRotationPeriod": (str, False),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (AmazonopensearchserviceRetryOptions, False),
        "RoleARN": (str, True),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3DestinationConfiguration, True),
        "TypeName": (str, False),
        "VpcConfiguration": (VpcConfiguration, False),
    }


class DeliveryStreamEncryptionConfigurationInput(AWSProperty):
    """
    `DeliveryStreamEncryptionConfigurationInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-deliverystreamencryptionconfigurationinput.html>`__
    """

    props: PropsDictType = {
        "KeyARN": (str, False),
        "KeyType": (str, True),
    }


class RetryOptions(AWSProperty):
    """
    `RetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-retryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class S3Configuration(AWSProperty):
    """
    `S3Configuration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-s3destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketARN": (str, True),
        "BufferingHints": (BufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "CompressionFormat": (str, False),
        "EncryptionConfiguration": (EncryptionConfiguration, False),
        "ErrorOutputPrefix": (str, False),
        "Prefix": (str, False),
        "RoleARN": (str, True),
    }


class ElasticsearchDestinationConfiguration(AWSProperty):
    """
    `ElasticsearchDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-elasticsearchdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BufferingHints": (BufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "ClusterEndpoint": (str, False),
        "DocumentIdOptions": (DocumentIdOptions, False),
        "DomainARN": (str, False),
        "IndexName": (str, True),
        "IndexRotationPeriod": (index_rotation_period_validator, False),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (RetryOptions, False),
        "RoleARN": (str, True),
        "S3BackupMode": (s3_backup_mode_elastic_search_validator, False),
        "S3Configuration": (S3Configuration, True),
        "TypeName": (str, False),
        "VpcConfiguration": (VpcConfiguration, False),
    }


class HiveJsonSerDe(AWSProperty):
    """
    `HiveJsonSerDe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-hivejsonserde.html>`__
    """

    props: PropsDictType = {
        "TimestampFormats": ([str], False),
    }


class OpenXJsonSerDe(AWSProperty):
    """
    `OpenXJsonSerDe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-openxjsonserde.html>`__
    """

    props: PropsDictType = {
        "CaseInsensitive": (boolean, False),
        "ColumnToJsonKeyMappings": (dict, False),
        "ConvertDotsInJsonKeysToUnderscores": (boolean, False),
    }


class Deserializer(AWSProperty):
    """
    `Deserializer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-deserializer.html>`__
    """

    props: PropsDictType = {
        "HiveJsonSerDe": (HiveJsonSerDe, False),
        "OpenXJsonSerDe": (OpenXJsonSerDe, False),
    }


class InputFormatConfiguration(AWSProperty):
    """
    `InputFormatConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-inputformatconfiguration.html>`__
    """

    props: PropsDictType = {
        "Deserializer": (Deserializer, False),
    }


class OrcSerDe(AWSProperty):
    """
    `OrcSerDe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-orcserde.html>`__
    """

    props: PropsDictType = {
        "BlockSizeBytes": (integer, False),
        "BloomFilterColumns": ([str], False),
        "BloomFilterFalsePositiveProbability": (double, False),
        "Compression": (str, False),
        "DictionaryKeyThreshold": (double, False),
        "EnablePadding": (boolean, False),
        "FormatVersion": (str, False),
        "PaddingTolerance": (double, False),
        "RowIndexStride": (integer, False),
        "StripeSizeBytes": (integer, False),
    }


class ParquetSerDe(AWSProperty):
    """
    `ParquetSerDe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-parquetserde.html>`__
    """

    props: PropsDictType = {
        "BlockSizeBytes": (integer, False),
        "Compression": (str, False),
        "EnableDictionaryCompression": (boolean, False),
        "MaxPaddingBytes": (integer, False),
        "PageSizeBytes": (integer, False),
        "WriterVersion": (str, False),
    }


class Serializer(AWSProperty):
    """
    `Serializer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-serializer.html>`__
    """

    props: PropsDictType = {
        "OrcSerDe": (OrcSerDe, False),
        "ParquetSerDe": (ParquetSerDe, False),
    }


class OutputFormatConfiguration(AWSProperty):
    """
    `OutputFormatConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-outputformatconfiguration.html>`__
    """

    props: PropsDictType = {
        "Serializer": (Serializer, False),
    }


class SchemaConfiguration(AWSProperty):
    """
    `SchemaConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-schemaconfiguration.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, False),
        "DatabaseName": (str, False),
        "Region": (str, False),
        "RoleARN": (str, False),
        "TableName": (str, False),
        "VersionId": (str, False),
    }


class DataFormatConversionConfiguration(AWSProperty):
    """
    `DataFormatConversionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-dataformatconversionconfiguration.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "InputFormatConfiguration": (InputFormatConfiguration, False),
        "OutputFormatConfiguration": (OutputFormatConfiguration, False),
        "SchemaConfiguration": (SchemaConfiguration, False),
    }


class DynamicPartitioningConfiguration(AWSProperty):
    """
    `DynamicPartitioningConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-dynamicpartitioningconfiguration.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "RetryOptions": (RetryOptions, False),
    }


class ExtendedS3DestinationConfiguration(AWSProperty):
    """
    `ExtendedS3DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-extendeds3destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketARN": (str, True),
        "BufferingHints": (BufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "CompressionFormat": (str, False),
        "DataFormatConversionConfiguration": (DataFormatConversionConfiguration, False),
        "DynamicPartitioningConfiguration": (DynamicPartitioningConfiguration, False),
        "EncryptionConfiguration": (EncryptionConfiguration, False),
        "ErrorOutputPrefix": (str, False),
        "Prefix": (str, False),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RoleARN": (str, True),
        "S3BackupConfiguration": (S3DestinationConfiguration, False),
        "S3BackupMode": (s3_backup_mode_extended_s3_validator, False),
    }


class HttpEndpointConfiguration(AWSProperty):
    """
    `HttpEndpointConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-httpendpointconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccessKey": (str, False),
        "Name": (str, False),
        "Url": (str, True),
    }


class HttpEndpointCommonAttribute(AWSProperty):
    """
    `HttpEndpointCommonAttribute <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-httpendpointcommonattribute.html>`__
    """

    props: PropsDictType = {
        "AttributeName": (str, True),
        "AttributeValue": (str, True),
    }


class HttpEndpointRequestConfiguration(AWSProperty):
    """
    `HttpEndpointRequestConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-httpendpointrequestconfiguration.html>`__
    """

    props: PropsDictType = {
        "CommonAttributes": ([HttpEndpointCommonAttribute], False),
        "ContentEncoding": (str, False),
    }


class HttpEndpointDestinationConfiguration(AWSProperty):
    """
    `HttpEndpointDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-httpendpointdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BufferingHints": (BufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "EndpointConfiguration": (HttpEndpointConfiguration, True),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RequestConfiguration": (HttpEndpointRequestConfiguration, False),
        "RetryOptions": (RetryOptions, False),
        "RoleARN": (str, False),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3DestinationConfiguration, True),
    }


class KinesisStreamSourceConfiguration(AWSProperty):
    """
    `KinesisStreamSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-kinesisstreamsourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "KinesisStreamARN": (str, True),
        "RoleARN": (str, True),
    }


class AuthenticationConfiguration(AWSProperty):
    """
    `AuthenticationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-authenticationconfiguration.html>`__
    """

    props: PropsDictType = {
        "Connectivity": (str, True),
        "RoleARN": (str, True),
    }


class MSKSourceConfiguration(AWSProperty):
    """
    `MSKSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-msksourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthenticationConfiguration": (AuthenticationConfiguration, True),
        "MSKClusterARN": (str, True),
        "TopicName": (str, True),
    }


class CopyCommand(AWSProperty):
    """
    `CopyCommand <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-copycommand.html>`__
    """

    props: PropsDictType = {
        "CopyOptions": (str, False),
        "DataTableColumns": (str, False),
        "DataTableName": (str, True),
    }


class RedshiftRetryOptions(AWSProperty):
    """
    `RedshiftRetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-redshiftretryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class RedshiftDestinationConfiguration(AWSProperty):
    """
    `RedshiftDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-redshiftdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "ClusterJDBCURL": (str, True),
        "CopyCommand": (CopyCommand, True),
        "Password": (str, True),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (RedshiftRetryOptions, False),
        "RoleARN": (str, True),
        "S3BackupConfiguration": (S3DestinationConfiguration, False),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3Configuration, True),
        "Username": (str, True),
    }


class SnowflakeRetryOptions(AWSProperty):
    """
    `SnowflakeRetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-snowflakeretryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class SnowflakeRoleConfiguration(AWSProperty):
    """
    `SnowflakeRoleConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-snowflakeroleconfiguration.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "SnowflakeRole": (str, False),
    }


class SnowflakeVpcConfiguration(AWSProperty):
    """
    `SnowflakeVpcConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-snowflakevpcconfiguration.html>`__
    """

    props: PropsDictType = {
        "PrivateLinkVpceId": (str, True),
    }


class SnowflakeDestinationConfiguration(AWSProperty):
    """
    `SnowflakeDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-snowflakedestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccountUrl": (str, True),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "ContentColumnName": (str, False),
        "DataLoadingOption": (str, False),
        "Database": (str, True),
        "KeyPassphrase": (str, False),
        "MetaDataColumnName": (str, False),
        "PrivateKey": (str, True),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (SnowflakeRetryOptions, False),
        "RoleARN": (str, True),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3DestinationConfiguration, True),
        "Schema": (str, True),
        "SnowflakeRoleConfiguration": (SnowflakeRoleConfiguration, False),
        "SnowflakeVpcConfiguration": (SnowflakeVpcConfiguration, False),
        "Table": (str, True),
        "User": (str, True),
    }


class SplunkBufferingHints(AWSProperty):
    """
    `SplunkBufferingHints <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-splunkbufferinghints.html>`__
    """

    props: PropsDictType = {
        "IntervalInSeconds": (integer, False),
        "SizeInMBs": (integer, False),
    }


class SplunkRetryOptions(AWSProperty):
    """
    `SplunkRetryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-splunkretryoptions.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (integer, False),
    }


class SplunkDestinationConfiguration(AWSProperty):
    """
    `SplunkDestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-splunkdestinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BufferingHints": (SplunkBufferingHints, False),
        "CloudWatchLoggingOptions": (CloudWatchLoggingOptions, False),
        "HECAcknowledgmentTimeoutInSeconds": (integer, False),
        "HECEndpoint": (str, True),
        "HECEndpointType": (str, True),
        "HECToken": (str, True),
        "ProcessingConfiguration": (ProcessingConfiguration, False),
        "RetryOptions": (SplunkRetryOptions, False),
        "S3BackupMode": (str, False),
        "S3Configuration": (S3DestinationConfiguration, True),
    }


class DeliveryStream(AWSObject):
    """
    `DeliveryStream <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesisfirehose-deliverystream.html>`__
    """

    resource_type = "AWS::KinesisFirehose::DeliveryStream"

    props: PropsDictType = {
        "AmazonOpenSearchServerlessDestinationConfiguration": (
            AmazonOpenSearchServerlessDestinationConfiguration,
            False,
        ),
        "AmazonopensearchserviceDestinationConfiguration": (
            AmazonopensearchserviceDestinationConfiguration,
            False,
        ),
        "DeliveryStreamEncryptionConfigurationInput": (
            DeliveryStreamEncryptionConfigurationInput,
            False,
        ),
        "DeliveryStreamName": (str, False),
        "DeliveryStreamType": (delivery_stream_type_validator, False),
        "ElasticsearchDestinationConfiguration": (
            ElasticsearchDestinationConfiguration,
            False,
        ),
        "ExtendedS3DestinationConfiguration": (
            ExtendedS3DestinationConfiguration,
            False,
        ),
        "HttpEndpointDestinationConfiguration": (
            HttpEndpointDestinationConfiguration,
            False,
        ),
        "KinesisStreamSourceConfiguration": (KinesisStreamSourceConfiguration, False),
        "MSKSourceConfiguration": (MSKSourceConfiguration, False),
        "RedshiftDestinationConfiguration": (RedshiftDestinationConfiguration, False),
        "S3DestinationConfiguration": (S3DestinationConfiguration, False),
        "SnowflakeDestinationConfiguration": (SnowflakeDestinationConfiguration, False),
        "SplunkDestinationConfiguration": (SplunkDestinationConfiguration, False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer
from .validators.appconfig import (
    validate_growth_type,
    validate_replicate_to,
    validate_validator_type,
)


class Application(AWSObject):
    """
    `Application <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-application.html>`__
    """

    resource_type = "AWS::AppConfig::Application"

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class Validators(AWSProperty):
    """
    `Validators <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-appconfig-configurationprofile-validators.html>`__
    """

    props: PropsDictType = {
        "Content": (str, False),
        "Type": (validate_validator_type, False),
    }


class ConfigurationProfile(AWSObject):
    """
    `ConfigurationProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-configurationprofile.html>`__
    """

    resource_type = "AWS::AppConfig::ConfigurationProfile"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "Description": (str, False),
        "KmsKeyIdentifier": (str, False),
        "LocationUri": (str, True),
        "Name": (str, True),
        "RetrievalRoleArn": (str, False),
        "Tags": (Tags, False),
        "Type": (str, False),
        "Validators": ([Validators], False),
    }


class Deployment(AWSObject):
    """
    `Deployment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-deployment.html>`__
    """

    resource_type = "AWS::AppConfig::Deployment"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "ConfigurationProfileId": (str, True),
        "ConfigurationVersion": (str, True),
        "DeploymentStrategyId": (str, True),
        "Description": (str, False),
        "EnvironmentId": (str, True),
        "KmsKeyIdentifier": (str, False),
        "Tags": (Tags, False),
    }


class DeploymentStrategy(AWSObject):
    """
    `DeploymentStrategy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-deploymentstrategy.html>`__
    """

    resource_type = "AWS::AppConfig::DeploymentStrategy"

    props: PropsDictType = {
        "DeploymentDurationInMinutes": (double, True),
        "Description": (str, False),
        "FinalBakeTimeInMinutes": (double, False),
        "GrowthFactor": (double, True),
        "GrowthType": (validate_growth_type, False),
        "Name": (str, True),
        "ReplicateTo": (validate_replicate_to, True),
        "Tags": (Tags, False),
    }


class Monitors(AWSProperty):
    """
    `Monitors <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-appconfig-environment-monitors.html>`__
    """

    props: PropsDictType = {
        "AlarmArn": (str, False),
        "AlarmRoleArn": (str, False),
    }


class Environment(AWSObject):
    """
    `Environment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-environment.html>`__
    """

    resource_type = "AWS::AppConfig::Environment"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "Description": (str, False),
        "Monitors": ([Monitors], False),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class Parameter(AWSProperty):
    """
    `Parameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-appconfig-extension-parameter.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "Required": (boolean, True),
    }


class Extension(AWSObject):
    """
    `Extension <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-extension.html>`__
    """

    resource_type = "AWS::AppConfig::Extension"

    props: PropsDictType = {
        "Actions": (dict, True),
        "Description": (str, False),
        "LatestVersionNumber": (integer, False),
        "Name": (str, True),
        "Parameters": (dict, False),
        "Tags": (Tags, False),
    }


class ExtensionAssociation(AWSObject):
    """
    `ExtensionAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-extensionassociation.html>`__
    """

    resource_type = "AWS::AppConfig::ExtensionAssociation"

    props: PropsDictType = {
        "ExtensionIdentifier": (str, False),
        "ExtensionVersionNumber": (integer, False),
        "Parameters": (dict, False),
        "ResourceIdentifier": (str, False),
        "Tags": (Tags, False),
    }


class HostedConfigurationVersion(AWSObject):
    """
    `HostedConfigurationVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html>`__
    """

    resource_type = "AWS::AppConfig::HostedConfigurationVersion"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "ConfigurationProfileId": (str, True),
        "Content": (str, True),
        "ContentType": (str, True),
        "Description": (str, False),
        "LatestVersionNumber": (double, False),
        "VersionLabel": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import integer
from .validators.route53resolver import validate_ruletype


class FirewallDomainList(AWSObject):
    """
    `FirewallDomainList <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-firewalldomainlist.html>`__
    """

    resource_type = "AWS::Route53Resolver::FirewallDomainList"

    props: PropsDictType = {
        "DomainFileUrl": (str, False),
        "Domains": ([str], False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class FirewallRule(AWSProperty):
    """
    `FirewallRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-firewallrulegroup-firewallrule.html>`__
    """

    props: PropsDictType = {
        "Action": (str, True),
        "BlockOverrideDnsType": (str, False),
        "BlockOverrideDomain": (str, False),
        "BlockOverrideTtl": (integer, False),
        "BlockResponse": (str, False),
        "FirewallDomainListId": (str, True),
        "Priority": (integer, True),
        "Qtype": (str, False),
    }


class FirewallRuleGroup(AWSObject):
    """
    `FirewallRuleGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-firewallrulegroup.html>`__
    """

    resource_type = "AWS::Route53Resolver::FirewallRuleGroup"

    props: PropsDictType = {
        "FirewallRules": ([FirewallRule], False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class FirewallRuleGroupAssociation(AWSObject):
    """
    `FirewallRuleGroupAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-firewallrulegroupassociation.html>`__
    """

    resource_type = "AWS::Route53Resolver::FirewallRuleGroupAssociation"

    props: PropsDictType = {
        "FirewallRuleGroupId": (str, True),
        "MutationProtection": (str, False),
        "Name": (str, False),
        "Priority": (integer, True),
        "Tags": (Tags, False),
        "VpcId": (str, True),
    }


class OutpostResolver(AWSObject):
    """
    `OutpostResolver <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-outpostresolver.html>`__
    """

    resource_type = "AWS::Route53Resolver::OutpostResolver"

    props: PropsDictType = {
        "InstanceCount": (integer, False),
        "Name": (str, True),
        "OutpostArn": (str, True),
        "PreferredInstanceType": (str, True),
        "Tags": (Tags, False),
    }


class ResolverConfig(AWSObject):
    """
    `ResolverConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverconfig.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverConfig"

    props: PropsDictType = {
        "AutodefinedReverseFlag": (str, True),
        "ResourceId": (str, True),
    }


class ResolverDNSSECConfig(AWSObject):
    """
    `ResolverDNSSECConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverdnssecconfig.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverDNSSECConfig"

    props: PropsDictType = {
        "ResourceId": (str, False),
    }


class IpAddressRequest(AWSProperty):
    """
    `IpAddressRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverendpoint-ipaddressrequest.html>`__
    """

    props: PropsDictType = {
        "Ip": (str, False),
        "Ipv6": (str, False),
        "SubnetId": (str, True),
    }


class ResolverEndpoint(AWSObject):
    """
    `ResolverEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverEndpoint"

    props: PropsDictType = {
        "Direction": (str, True),
        "IpAddresses": ([IpAddressRequest], True),
        "Name": (str, False),
        "OutpostArn": (str, False),
        "PreferredInstanceType": (str, False),
        "Protocols": ([str], False),
        "ResolverEndpointType": (str, False),
        "SecurityGroupIds": ([str], True),
        "Tags": (Tags, False),
    }


class ResolverQueryLoggingConfig(AWSObject):
    """
    `ResolverQueryLoggingConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverqueryloggingconfig.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverQueryLoggingConfig"

    props: PropsDictType = {
        "DestinationArn": (str, False),
        "Name": (str, False),
    }


class ResolverQueryLoggingConfigAssociation(AWSObject):
    """
    `ResolverQueryLoggingConfigAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverqueryloggingconfigassociation.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation"

    props: PropsDictType = {
        "ResolverQueryLogConfigId": (str, False),
        "ResourceId": (str, False),
    }


class TargetAddress(AWSProperty):
    """
    `TargetAddress <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverrule-targetaddress.html>`__
    """

    props: PropsDictType = {
        "Ip": (str, False),
        "Ipv6": (str, False),
        "Port": (str, False),
        "Protocol": (str, False),
    }


class ResolverRule(AWSObject):
    """
    `ResolverRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverRule"

    props: PropsDictType = {
        "DomainName": (str, True),
        "Name": (str, False),
        "ResolverEndpointId": (str, False),
        "RuleType": (validate_ruletype, True),
        "Tags": (Tags, False),
        "TargetIps": ([TargetAddress], False),
    }


class ResolverRuleAssociation(AWSObject):
    """
    `ResolverRuleAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverruleassociation.html>`__
    """

    resource_type = "AWS::Route53Resolver::ResolverRuleAssociation"

    props: PropsDictType = {
        "Name": (str, False),
        "ResolverRuleId": (str, True),
        "VPCId": (str, True),
    }



import unittest

from troposphere import If, Ref
from troposphere.autoscaling import AutoScalingGroup
from troposphere.policies import AutoScalingRollingUpdate, UpdatePolicy


class TestAutoScalingGroup(unittest.TestCase):
    def test_exclusive(self):
        group = AutoScalingGroup(
            "mygroup",
            InstanceId="i-1234",
            LaunchConfigurationName="I'm a test",
            MaxSize="1",
            MinSize="1",
        )
        with self.assertRaises(ValueError):
            group.validate()

    def test_none(self):
        group = AutoScalingGroup(
            "mygroup",
            MaxSize="1",
            MinSize="1",
        )
        with self.assertRaises(ValueError):
            group.validate()

    def test_instanceid(self):
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            InstanceId="i-1234",
            MaxSize="1",
            MinSize="1",
        )
        self.assertIsNone(group.validate())

    def test_launchconfigurationname(self):
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize="1",
            MinSize="1",
        )
        self.assertIsNone(group.validate())

    def test_size_if(self):
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize=If("isstage", "1", "5"),
            MinSize="1",
            UpdatePolicy=UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                    PauseTime="PT5M",
                    MinInstancesInService="1",
                    MaxBatchSize="1",
                    WaitOnResourceSignals=True,
                )
            ),
        )
        self.assertIsNone(group.validate())

    def test_helperfn_as_updatepolicy(self):
        update_policy = UpdatePolicy(
            AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                PauseTime="PT5M",
                MinInstancesInService="1",
                MaxBatchSize="1",
                WaitOnResourceSignals=True,
            )
        )
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize=If("isstage", "1", "5"),
            MinSize="1",
            UpdatePolicy=If("UseUpdatePolicy", update_policy, Ref("AWS::NoValue")),
        )
        self.assertIsNone(group.validate())

    def test_helperfn_as_AutoScalingRollingUpdate(self):
        update_policy = UpdatePolicy(
            AutoScalingRollingUpdate=If(
                "RollingUpdate",
                AutoScalingRollingUpdate(
                    PauseTime="PT5M",
                    MinInstancesInService="1",
                    MaxBatchSize="1",
                    WaitOnResourceSignals=True,
                ),
                Ref("AWS::NoValue"),
            ),
        )
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize=If("isstage", "1", "5"),
            MinSize="1",
            UpdatePolicy=If("UseUpdatePolicy", update_policy, Ref("AWS::NoValue")),
        )
        self.assertIsNone(group.validate())

    def test_AutoScalingRollingUpdate_all_defaults(self):
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize="1",
            MinSize="1",
            UpdatePolicy=UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate()
            ),
        )
        self.assertIsNone(group.validate())

    def test_AutoScalingRollingUpdate_validation(self):
        update_policy = UpdatePolicy(
            AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                MinInstancesInService="2", MaxBatchSize="1"
            )
        )
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize="2",
            MinSize="1",
            UpdatePolicy=update_policy,
        )

        with self.assertRaises(ValueError):
            group.validate()


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


WebServer = "WebServer"
Worker = "Worker"
WebServerType = "Standard"
WorkerType = "SQS/HTTP"


def validate_tier_name(name):
    """
    Property: Tier.Name
    """
    valid_names = [WebServer, Worker]
    if name not in valid_names:
        raise ValueError("Tier name needs to be one of %r" % valid_names)
    return name


def validate_tier_type(tier_type):
    """
    Property: Tier.Type
    """
    valid_types = [WebServerType, WorkerType]
    if tier_type not in valid_types:
        raise ValueError("Tier type needs to be one of %r" % valid_types)
    return tier_type
